import { IAspect, IConstruct } from "@aws-cdk/core";
/**
 * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html
 */
export declare class AWSFoundationalSecurityBestPracticesChecker implements IAspect {
    visit(node: IConstruct): void;
    private checkLamdaCompliance;
    /**
     * [Lambda.1] Lambda function policies should prohibit public access
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-lambda-1
     */
    private checkLambdaPublicAccess;
    private supportedLambdaRuntimes;
    /**
     * [Lambda.2] Lambda functions should use supported runtimes
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-lambda-2
     */
    private checkLambdaSupportedRuntime;
    private checkIAMPolicyCompliance;
    /**
     * [IAM.1] IAM policies should not allow full "*" administrative privileges.
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-1
     */
    private checkIAMPolicyFullAdmin;
    /**
     * [IAM.21] IAM customer managed policies that you create should not allow wildcard actions for services
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-iam-21
     */
    private checkIAMPolicyServiceWildcards;
}
